Pootle 2.1.6 — Pootle 2.5.1 documentation

# Pootle 2.1.6

Released on 13 April 2011

It’s been 3 months since our last bug fix releases, it’s about time we give you Pootle 2.1.6.

Pootle is a web based system for translation and translation management.

Main focus of the release is incompatibility issues with the latest versions of Django (1.2.5 and 1.3.0).

Apart from that, version 2.1.6 has a handful of fixes. Here are the highlights:

- Fixed another bug with GNU style projects language detection.
- Added a separate project type for UTF-8 encoded Java properties.
- Fixed a bug that would under rare conditions hide some strings from translate page.
- Fixed a bug that caused some translation project level statistics to be miscalculated.
- Fix for Qt TS format based on changes in Translate Toolkit 1.9.0

On the first visit after upgrading upgrade screen will flash for a short period while translation statistics are recalculated, if running under Translate Toolkit version 1.9.0 it might last longer as Qt TS files will be reparsed to benefit from improvements to the format support.

Django 1.2.5 and 1.3.0 compatibility depends on Translate Toolkit version 1.9.0 or above but all users are encouraged to upgrade their versions of Translate Toolkit. As always Pootle will benefit from fixes and performance improvements in the latest versions.

- Feature list
- Download
- Installation instructions
- Bugs
- More information